"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import turbinia_api_lib
from turbinia_api_lib.api.turbinia_requests_api import TurbiniaRequestsApi  # noqa: E501


class TestTurbiniaRequestsApi(unittest.TestCase):
    """TurbiniaRequestsApi unit test stubs"""

    def setUp(self):
        self.api = TurbiniaRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_request(self):
        """Test case for create_request

        Create Request  # noqa: E501
        """
        pass

    def test_get_request_status(self):
        """Test case for get_request_status

        Get Request Status  # noqa: E501
        """
        pass

    def test_get_requests_summary(self):
        """Test case for get_requests_summary

        Get Requests Summary  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
