"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import turbinia_api_lib
from turbinia_api_lib.model.validation_error_loc_inner import ValidationErrorLocInner
globals()['ValidationErrorLocInner'] = ValidationErrorLocInner
from turbinia_api_lib.model.validation_error import ValidationError


class TestValidationError(unittest.TestCase):
    """ValidationError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testValidationError(self):
        """Test ValidationError"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ValidationError()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
