"""
    Turbinia API Server

    Turbinia API server  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import turbinia_api_lib
from turbinia_api_lib.model.base_request_options import BaseRequestOptions
globals()['BaseRequestOptions'] = BaseRequestOptions
from turbinia_api_lib.model.request import Request


class TestRequest(unittest.TestCase):
    """Request unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRequest(self):
        """Test Request"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Request()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
